// Camera.h
#ifndef CAMERA_H
#define CAMERA_H

#include "VectorUtils4.h"

class Camera {
private:
    vec3 campos;
    vec3 forward;
    vec3 upVector;
    float fov;
    float aspectRatio;
    float zNear;
    float zFar;
    bool displayBorder = false;
    mat4 rotationMatrix;

    void rotateSide(float angle);
    void rotateUp(float angle);

public:
    Camera(vec3 position, vec3 target, vec3 up, float fov, float aspect, float zNear, float zFar);
    void processKey(unsigned char key);
    void reshape(int width, int height);
    mat4 getViewMatrix() const;
    mat4 getProjectionMatrix() const;
    bool shouldDisplayBorder() const { return displayBorder; }
    void toggleDisplayBorder() { displayBorder = !displayBorder; }
    void setAspectRatio(float aspect) { aspectRatio = aspect; }
};

void initCamera(Camera& camera);

#endif
