// PCISPH_sim.h
#ifndef KERNELS_CUDA_H
#define KERNELS_CUDA_H

#include <cuda_runtime.h>
#include <cuda_gl_interop.h>
#include <vector>

extern const int NUM_PARTICLES;

void updateParticles(float deltaTime);
void registerVBOWithCUDA(unsigned int vbo);
void registerBoundaryVBOWithCUDA(unsigned int vbo);
void unregisterVBOFromCUDA();
void unregisterBoundaryVBOFromCUDA();
void initializeConstants();
void boundaryNBSearch(int numBoundaryParticles);

void neigbourHoodSearch(
        int nParticles, 
        float3* d_pos,
        float3* d_vel,
        float3* d_posSorted,
        float3* d_velSorted,
        unsigned int* d_cellIndc,
        unsigned int* d_parIndc,
        unsigned int* d_cEnd,
        unsigned int* d_cStart,
        const int bpg,
        const int tpb, 
        int &gridSizeX,
        int &gridSizeY,
        int &gridSizeZ
); 

void initializeFluidDeviceArrays(
    const float3* h_positions,
    const float3* h_velocities,
    int numParticles
);

void initializeBoundryDeviceArrays(
    const float3* h_boundaryPositions,
    const float3* h_boundaryVelocities,
    int numBoundaryParticles
);

void cleanupDeviceArrays();

#endif // KERNELS_CUDA_H
