#version 330 core

in vec3 vEyeSpacePos;

uniform mat4 projectionMatrix;
uniform float sphereRadius;
uniform float zNear;
uniform float zFar;

out vec4 FragColor; // Color output for depth visualization

void main()
{
    // Convert gl_PointCoord from [0,1] to [-1,1]
    vec2 texCoord = gl_PointCoord * 2.0 - 1.0;
    float r2 = dot(texCoord, texCoord);

    // Discard fragments outside the circle to form a sphere silhouette
    if (r2 > 1.0)
        discard;

    // Calculate the sphere's surface normal offset in eye-space
    float z = sqrt(1.0 - r2);
    vec3 N = vec3(texCoord, z);

    // Compute the fragment's actual position on the sphere surface in eye space
    vec3 pixelPos = vEyeSpacePos + N * sphereRadius;

    // Compute linear depth (distance from camera)
    float linearDepth = length(pixelPos); // Distance from camera in eye-space

    // Normalize linear depth to [0, 1]
    float normalizedDepth = (linearDepth - zNear) / (zFar - zNear);
    normalizedDepth = clamp(normalizedDepth, 0.0, 1.0);

    // Output the linear depth as grayscale
    FragColor = vec4(vec3(normalizedDepth), 1.0);
}