#version 330 core

out vec4 FragColor;

// Uniform for light direction
//uniform vec3 lightDir; // Should be normalized
uniform vec3 uColor; 

void main()
{
    // Calculate normalized coordinates from -1 to 1
    vec3 lightDir = normalize(vec3(0.0, -5.0, 5.0));
    vec2 coord = gl_PointCoord * 2.0 - 1.0; // Range from -1 to 1
    float dist = length(coord);

    if(dist > 1.0)
        discard; // Discard fragments outside the circle

    // Compute normal vector assuming a hemisphere
    vec3 normal = vec3(coord, sqrt(1.0 - dist * dist));

    // Normalize the light direction
    vec3 lightDirection = normalize(lightDir);

    // Calculate diffuse lighting (Lambertian reflection)
    float diffuse = max(dot(normal, lightDirection), 0.0);

    // Base color (you can modify this or make it a uniform)
    vec3 baseColor = uColor;//vec3(0.29, 0.573, 1.0); // Pleasant blue color

    // Apply lighting to the base color
    vec3 shadedColor = baseColor * diffuse;

    FragColor = vec4(shadedColor, 1.0); // Solid color with full opacity
}
