#version 330 core

layout(location = 0) in vec3 aPosition;  // or "aPos" if that matches your code

// Same transforms as depth
uniform mat4 modelMatrix;
uniform mat4 viewMatrix;
uniform mat4 projectionMatrix;

// The same pointSize logic
uniform float pointRadius;
uniform float pointScale;

out vec3 vEyeSpacePos;

void main()
{
    // Transform the particle's position from model to eye space
    vec4 worldPos = modelMatrix * vec4(aPosition, 1.0);
    vec4 eyePos   = viewMatrix * worldPos;
    vEyeSpacePos  = eyePos.xyz;
    
    // Scale point size based on distance, like your depth pass
    float dist = length(eyePos.xyz);
    gl_PointSize = pointRadius * (pointScale / dist);

    // Standard projection
    gl_Position = projectionMatrix * eyePos;
}
