#version 330 core

in vec2 TexCoords;
out vec4 FragColor;

// The blurred thickness texture
uniform sampler2D uThicknessTex;

// Absorption coefficient
uniform float alphaScale; // e.g. 3.0 -> the higher, the more quickly light fades

// The color of the fluid (if you want tinted absorption)
uniform vec3 absorptionRGB; // e.g. vec3(0.3, 0.7, 1.0)

void main()
{
    float thicknessVal = texture(uThicknessTex, TexCoords).r;

    // Beer–Lambert law
    //float attenuation = exp(-absorption * thicknessVal);

    vec3 attenuationRGB = exp(-absorptionRGB * thicknessVal);
    // The fluid color modulated by that attenuation 
    // (This is a simplistic approach: if you want the fluid 
    //  to be fully absorbing, you do: finalColor = fluidColor * (1 - attenuation), etc.)
    //vec3 color = fluidColor * (1 - attenuation);
    //FragColor = vec4(color, 1.0);
    float alpha = 0;

    if(thicknessVal < 0.001) {
        // Background
        alpha = 0;
    } else
    {
        float avgAttenuation = (attenuationRGB.x + attenuationRGB.y + attenuationRGB.z) / 3.0;
        alpha = clamp((1.0 -  avgAttenuation )*alphaScale, 0.0, 1.0);
    }

    FragColor = vec4(attenuationRGB, alpha);
}
