#version 330 core

in vec2 TexCoords;
out vec4 FragColor;

// The original thickness texture (GL_R32F storing thickness in .r)
uniform sampler2D uThicknessTex;

// Parameters for blur
uniform vec2 passDirection; // e.g. (1.0/width, 0) or (0, 1.0/height)
uniform int kernelRadius;   // e.g. 5, 10, etc.
uniform float gaussWeights[64]; // Precomputed half-kernel weights up to radius=63

void main()
{
    // Sample center
    float centerVal = texture(uThicknessTex, TexCoords).r;

    if (centerVal < 0.005) discard;

    // Accumulate for a 1D Gaussian blur
    float sum = 0.0;
    float wSum = 0.0;

    for (int i = -kernelRadius; i <= kernelRadius; i++)
    {
        // offset in texture space
        vec2 offset = passDirection * float(i);
        vec2 sampleUV = TexCoords + offset;

        float sampleVal = texture(uThicknessTex, sampleUV).r;

        //if (sampleVal < 0.01) continue;

        // Spatial weight from precomputed array
        float w = gaussWeights[abs(i)];

        sum  += sampleVal * w;
        wSum += w;
    }

    float blurredVal = sum / max(wSum, 1e-5);
    FragColor = vec4(blurredVal, 0.0, 0.0, 1.0);
}
