#ifndef CUDA_DEVICE_VARS_H
#define CUDA_DEVICE_VARS_H

#include <cuda_runtime.h>

namespace FluidSimulationGPU {


// Global Variables
extern cudaGraphicsResource_t cuda_vbo_resource;
extern cudaGraphicsResource_t cuda_vbo_boundary_resource;

// Constants
extern __constant__ float PI;
extern __constant__ float H;
extern __constant__ float H2;
extern __constant__ float K_PCI;
extern __constant__ float POLY6_CONST;
extern __constant__ float SPIKY_GRAD_CONST;
extern __constant__ float VISC_LAP_CONST;

extern __constant__ float POLY6_D1_CONST;
extern __constant__ float SURFACE_TENS_CONST;
extern __constant__ float SURFACE_TENS_TERM;
extern __constant__ float SURFACE_TENS_COEFFICIENT;

extern __constant__ float PARTICLE_MASS;
extern __constant__ float REST_DENSITY;
extern __constant__ float VISCOSITY;

// Boundary constants
extern __constant__ float BOUND_X_MIN;
extern __constant__ float BOUND_X_MAX;
extern __constant__ float BOUND_Y_MIN;
extern __constant__ float BOUND_Y_MAX;
extern __constant__ float BOUND_Z_MIN;
extern __constant__ float BOUND_Z_MAX;

// Device Arrays
extern float3* d_positions;
extern float3* d_velocities;

extern unsigned int* d_cellIndices;
extern unsigned int* d_particleIndices;

extern float3* d_positions_sorted;
extern float3* d_velocities_sorted;

extern unsigned int* d_cellStart;
extern unsigned int* d_cellEnd;

// Arrays for densities, pressures, accelerations
extern float* d_densities;
extern float* d_density_errors;
extern float* d_pressure_increments;
extern float3* d_pressure_forces;
extern float3* d_accelerations;
extern float3* d_normals;

// Additional arrays for PCISPH
extern float3* d_velocities_pred;
extern float3* d_positions_pred;
extern float* d_sum_gradW2; // For computing A

// Boundary particles
extern float3* d_boundary_positions;
extern float3* d_boundary_normals;

extern unsigned int* d_boundaryCellStart;
extern unsigned int* d_boundaryCellEnd;

extern unsigned int* d_boundaryCellIndices;
extern unsigned int* d_boundaryParticleIndices;

}
#endif // CUDA_DEVICE_VARS_H