#ifndef INIT_CUDA_H
#define INIT_CUDA_H

#include <cuda_runtime.h>

namespace FluidSimulationGPU {

// Initialize constant values for the simulation
void initializeConstants();

// Register and unregister VBOs for CUDA-OpenGL interoperability
void registerVBOWithCUDA(unsigned int vbo);
void registerBoundaryVBOWithCUDA(unsigned int vbo);
void unregisterVBOFromCUDA();
void unregisterBoundaryVBOFromCUDA();

// Initialize device memory for fluid and boundary particles
void initializeFluidDeviceArrays(const float3* h_positions, const float3* h_velocities, int numParticles);
void initializeBoundryDeviceArrays(const float3* h_boundaryPositions, const float3* h_boundaryVelocities, int numBoundaryParticles);

// Cleanup all device arrays
void cleanupDeviceArrays();

// Perform a one-time neighborhood search for static boundary particles
void boundaryNBSearch(int numBoundaryParticles);

void resetSimulation(
    const float3* h_positions,
    const float3* h_velocities,
    int numParticles
);

void updateConstantsOnDevice(
    float particleMass,
    float restDensity, 
    float viscosity, 
    float smoothingRadius
);

void ComputePCISPHStiffness(
    float timeStep,
    float particleMass,
    float restDensity,
    float kernelRadius,
    float restSpacing,
    float spiky_d1_normalization
);

} // namespace FluidSimulationGPU

#endif // INIT_CUDA_H
