#include "include/smoothing_kernels.h"
#include "include/cuda_device_vars.h"
#include "../settings/constants.h" // Dont ned this one?

namespace FluidSimulationGPU {

__device__ float poly6Kernel(float r2)
{
    if (r2 >= 0.0f && r2 <= H2) {
        float term = H2 - r2;
        return POLY6_CONST * term * term * term;
    } else {
        return 0.0f;
    }
}

__device__ float kernel_poly6_d1(float r2) {
	
    if(r2 > H2) {
		return 0.f;
	} else {
        float term = r2 - H2;
		return term * term; // * r need to multiply my diff in calulation
	}
}


__device__ float spikyKernelGrad(float r)
{
    if (r > 0.0f && r <= H) {
        float term = H - r;
        return SPIKY_GRAD_CONST * term * term;
    } else {
        return 0.0f;
    }
}

__device__ float viscosityKernelLap(float r)
{
    if (r >= 0.0f && r <= H) {
        return VISC_LAP_CONST * (H - r);
    } else {
        return 0.0f;
    }
}

__device__ float kernel_surface_tension(float r) {
	if( r <= 0.5 * H ) {
		float t1 = (H - r);
		float t2 = (t1 * t1 * t1) * (r * r * r);
		return 2.f * t2 - SURFACE_TENS_TERM;
	}
	else if( r <= H ) {
		float t1 = (H - r);
		return (t1 * t1 * t1) * (r * r * r);
	}
	else {
		return 0.f;
	}
}

} // namespace FluidSimulationGPU
