#pragma once

#include "VectorUtils4.h"

namespace FluidSimulation {

    class Camera {
    private:
        vec3 campos;
        vec3 forward;
        vec3 upVector;
        float fov;
        float aspectRatio;
        float zNear;
        float zFar;
        bool displayBorder = false;
        mat4 rotationMatrix;

        vec3 m_light_pos;

        void rotateSide(float angle);
        void rotateUp(float angle);

    public:
        Camera(vec3 position, vec3 target, vec3 up, float fov, float aspect, float zNear, float zFar);
        void processKey(unsigned char key);
        void reshape(int width, int height);
        mat4 getViewMatrix() const;
        mat4 getProjectionMatrix() const;
        bool shouldDisplayBorder() const { return displayBorder; }
        void toggleDisplayBorder() { displayBorder = !displayBorder; }
        void setAspectRatio(float aspect) { aspectRatio = aspect; }
        float getNearPlane() { return zNear; };
        float getFarPlane() { return zFar; };
        float getFovyRadians() const;

        void setEyeSpacePosition(vec3 light_pos) { m_light_pos = light_pos; };
        vec3 getEyeSpacePosition() const; 
        vec3 getLightPosition() const { return m_light_pos; };
    

    };

    void initCamera(Camera& camera);

} // namespace FluidSimulation
