#pragma once

#include <vector>
#include <cuda_runtime.h>
#include <GL/glew.h>
#include "SimulationMode.h"

namespace FluidSimulation {

    class FluidSimulation {
    private:
        GLuint m_vbo_particles;
        GLuint m_vbo_boundary;

        int m_numParticles;
        int m_numBoundaryParticles;

        float m_timeStep;

        float m_particleMass;
        float m_restDensity;
        float m_viscosity;
        float m_smoothingRadius;
        int m_simulationStepsPerFrame;

        SimulationMode m_mode;

    public:
        FluidSimulation(int numParticles);
        ~FluidSimulation();

        void initSimulation();  // Initialize simulation resources
        void updateSimulation();  // Update particles using CUDA
        void Reset();

        GLuint getParticleVBO() const { return m_vbo_particles; }
        GLuint getBoundaryVBO() const { return m_vbo_boundary; }

        int getParticleCount() const { return m_numParticles; };
        int getBoundaryParticleCount() const { return m_numBoundaryParticles; };
        
        void updateConstants();

        float getParticleMass() { return m_particleMass; }
        float getRestDensity() { return m_restDensity; }
        float getViscosity() { return m_viscosity; }
        float getSmoothingRadius() { return m_smoothingRadius; }

        int getSimulationStepsPerFrame() { return m_simulationStepsPerFrame; };
        SimulationMode getSimulationMode() { return m_mode; };

        void setParticleMass(float particleMass) { m_particleMass = particleMass; };
        void setRestDensity(float restDensity) { m_restDensity = restDensity; };
        void setViscosity(float visocisty) { m_viscosity = visocisty; };
        void setSmoothingRadius(float smoothRadius) { m_smoothingRadius = smoothRadius; };
    
        void setSimulationStepsPerFrame(int steps) { m_simulationStepsPerFrame = steps; };
        void setSimulationMode(SimulationMode newMode);

        void ResetFluidParameters();
    };

}
